require 'csv'
require "worldcup/version"

module Worldcup
  class Team
    attr_reader :country
    attr_reader :coach
    attr_reader :group

    private

    def initialize(country, coach, group)
      @country = country
      @coach = coach
      @group = group

      freeze

      self.class.instance_variable_get(:@teams).tap do |teams|
        teams[@country.downcase]  = self
      end

      self
    end

    public

    def self.all
      @teams.values
    end

    def self.find(name)
      result = @teams[name.downcase]

      raise(RuntimeError, "No team found for lookup '#{name}'") unless result

      result
    end

    @teams = {}
    data_file = File.expand_path('../../data/team.txt', __FILE__)
    options = { col_sep: '|', headers: true, header_converters: :symbol }

    CSV.foreach(data_file, options) do |row|
      new row[:country], row[:coach], row[:group]
    end

    @teams.values.map &:freeze
    @teams.freeze

    freeze
  end
end
